==> ModuleXtender-1.5.0.zip: ModuleXtender/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Module Xtender';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Post Uninstall Message, e.g., "Curses! Foiled Again!"';
$lang['really_uninstall'] = 'Really? Are you sure you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module extend compatibles modules to give them more stuffs like a categories/pages relation system, a form field extender system, etc.';

$lang['error'] = 'Error!';
$lang['submit'] = 'Submit';
$lang['apply'] = 'Apply';
$lang['upload'] = 'Upload';
$land['admin_title'] = 'Module Xtender Admin Panel';
$lang['admindescription'] = 'Manage here all your relations, module form extender, etc';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Post Install Message, (e.g., Be sure to set "" permissions to use this module!)';

$lang['modulenotdefined'] = 'Module not defined';
$lang['manage_relations'] = 'Manage relations';
$lang['noidfound'] = 'Item not found';

$lang['title_move'] = 'Move';
$lang['move_up'] = 'Move up';
$lang['move_down'] = 'Move down';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';

$lang['show'] = 'Show';
$lang['hide'] = 'Hide';

$lang['filter'] = 'Filter';
$lang['is_filter'] = 'Is a filter';
$lang['is_not_filter'] = 'Is not a filter';
$lang['is_sortable'] = 'Is sortable';
$lang['is_not_sortable'] = 'Is not sortable';
$lang['column'] = 'Column';
$lang['have_column'] = 'Have column';
$lang['dont_have_column'] = 'Do not have column';

$lang['image_file_error'] = 'An error occured with the image file.';

// TABS

$lang['devtab'] = 'Developpment Tab';
$lang['settings'] = 'Settings';
$lang['xtendedmodules'] = 'Xtended Modules';
$lang['moduleuninstalled'] = 'The module have been uninstalled !';
$lang['activemodule'] = 'Activate the module Xtended features';
$lang['desactivemodule'] = 'Desactivate the module Xtended features';

// Xtend part

$lang['isactive'] = 'Active';
$lang['option_documents_title'] = 'Show documents';
$lang['option_images_title'] = 'Show images';
$lang['option_links_title'] = 'Show links';
$lang['option_relations_title'] = 'Show relations';

// RELATIONS
$lang['relations'] = 'Relations';
$lang['rel_type_page'] = 'Page';
$lang['rel_type_pages'] = 'Subpages';
$lang['rel_type_page_and_subpages'] = 'Page & subpages';
$lang['rel_type_category'] = 'Category';
$lang['activeate_rel'] = 'Activate relation';
$lang['desactiveate_rel'] = 'Desactivate relation';

$lang['select_cat'] = 'Select a category';
$lang['select_category'] = 'Select a category';
$lang['select_module'] = 'Select a module';
$lang['add_cat'] = 'Add category';
$lang['add_page'] = 'Add page';
$lang['related_pages'] = 'Related pages';


$lang['title_type'] = 'Type';
$lang['title_visible'] = 'Show';
$lang['title_subpage'] = 'Subpage';
$lang['title_category'] = 'Category';
$lang['title_module'] = 'Module';
$lang['title_page'] = 'Page';
$lang['relation_title'] = 'Title';
$lang['edit_relation_title'] = 'Edit title';
$lang['edit_relation_title_for'] = 'Edit title for ';

$lang['title_is_filter'] = 'Is filter';
$lang['title_is_sortable'] = 'Is sortable';

$lang['manage_relations_for'] = 'Manage relations for';

// CATEGORIES / OPTIONS
$lang['categories'] = 'Categories';
$lang['title_category_name'] = 'Category name';
$lang['title_add_new_category'] = 'New category';
$lang['title_add_edit_category'] = 'Add/Edit category';
$lang['edit_cat'] = 'Edit category';
$lang['title_option_name'] = 'Option name';
$lang['title_add_new_option'] = 'New option';
$lang['title_add_edit_option'] = 'Add/Edit option';
$lang['add_option'] = 'Add option';
$lang['edit_option'] = 'Edit option';
$lang['optionadded'] = 'Option added';
$lang['optionmodified'] = 'Option modified';
$lang['optiondeleted'] = 'Option deleted';

$lang['reorder_options_alpha'] = 'Reorder options alphabeticaly';


$lang['options'] = 'Options';

$lang['options_apply_first'] = 'To add options, click on "apply" first.';
$lang['add_option_for'] = 'Add option for';

// CUSTOM FIELDS LIST
$lang['customfields'] = 'Custom Fields';
$lang['title_add_customfields'] = 'Add custom field';

// TEMPLATES

$lang['templates'] = 'Templates list';
$lang['title_list_template'] = 'Templates list';
$lang['title_details_template'] = 'Details template';
$lang['deleteTemplate'] = 'Delete template';
$lang['editTemplate'] = 'Edit template';
$lang['titleTemplate'] = 'Template name';
$lang['codeTemplate'] = 'Template code';
$lang['restorelist'] = 'Get default list template';
$lang['restoredetails'] = 'Get default details template';
$lang['title_add_template'] = 'Add template';


$lang['assigned_to'] = 'Assigned to';
$lang['get_default_template'] = 'Get default template from';
$lang['unknown_template'] = 'Unknown template';


$lang['fe.select'] = 'Select one';
$lang['fe.general'] = 'General frontend';
$lang['fe.documents'] = 'Frontend documents';
$lang['fe.images'] = 'Frontend images';
$lang['fe.pages'] = 'Frontend pages';
$lang['fe.categories'] = 'Frontend categories';


// Countries
$lang['countries_select'] = 'Select a country';

// Divers
$lang['title_selectmodule'] = 'Module';
$lang['selectmodule_button'] = 'Select module';
$lang['selectmodule_default'] = 'Select module';
$lang['areyousure'] = 'Are you sure ?';
$lang['cancel'] = 'Cancel';
$lang['firstapplydoc'] = 'First push on "Apply" to be able to add documents';
$lang['firstapplyimg'] = 'First push on "Apply" to be able to add images';
$lang['firstapplylink'] = 'First push on "Apply" to be able to add links';
$lang['tips'] = 'Tips:';
$lang['tips1'] = 'To select multiple relations use CTRL+Click.<br />To unselect an item, use CTRL+Click.';
$lang['title'] = 'Title';
$lang['caption'] = 'Caption';
$lang['file'] = 'File';

$lang['document'] = 'Document';
$lang['documents'] = 'Documents';

$lang['image'] = 'Image';
$lang['images'] = 'Images';
$lang['rebuild_thumbnails'] = 'Rebuild thumbnails';
$lang['reset_sizes'] = 'Reset image sizes';

$lang['link'] = 'Link';
$lang['links'] = 'Links';
$lang['popup_link'] = 'Popup link';
$lang['popup_link_question'] = 'Popup link?';
$lang['is_new_window'] = 'Show in new window';
$lang['isnt_new_window'] = 'Dont show in new window';
$lang['url'] = 'Url';


// Related categories

$lang['related_categories'] = 'Related categories';
$lang['manage_related_categories_for'] = 'Manage %2 related categories for module %1';
$lang['back_to_xtended'] = 'Return to %1 options list';
$lang['manage_related_categories'] = 'Manage related categories';

// Divers
$lang['cleanup'] = 'Cleanup module';
$lang['load_deprecated_features'] = 'Load deprecated features'; 


// ModuleXtender Smarty Available fields

$lang['smarty_fields'] = '
<ul>
  <li>$item->xtended_felist</li>
</ul>';



$lang['changelog'] = '<ul>
<li>Version 0.1.15 - 27 july 2009. Add related links</li>
<li>Version 0.1.14 - 25 july 2009. Add lot of stuff</li>
<li>Version 0.0.5 - 17 january 2009. Add the ability to make relation to page and subpages and clean some stuff.</li>
<li>Version 0.0.4.3 - 16 april 2008. Add several features and fixes.</li>
<li>Version 0.0.2.6 - 16 october 2007. Correct thumbs size calculation.</li>
<li>Version 0.0.2.5 - 15 october 2007. First official Release.</li>
<li>Version 0.0.1 - 24 August 2007. Initial Release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module extend compatibles modules to give them more stuffs like a categories/pages relation system, a form field extender system, etc.</p>
<h3>How Do I Use It</h3>
<p>It will generate appropriate fields in the compatible module, in the frontend and the backend.</p>

<h3>What Parameters Does It Take</h3>
<p>This take many parameters. Here is a short list of it.</p>
<ul>
  <li><strong>pages</strong> Filter on given pages id separate by a ",".</li>
  <li><strong>subpages</strong> Filter on subpages from given page id.</li>
  <li><strong>currentpage</strong> Filter on current page.</li>
  <li><strong>category</strong> Filter on given category id.</li>
  <li><strong>categories</strong> Filter on given categories id separate by a ",".</li>
  <li><strong>filter_on</strong> filters on different attributes. The form is filter_on="type1|params||type2|params" where types can be "pages", "categories", and "field". For field, the params are like filter_on="field|fieldname=value".</li>
</ul>
<p>&nbsp;</p>
<h3>Front End Actions</h3>
<p>&nbsp;</p>
<h4>Default</h4>
<p>Deprecated: Prefere the use of "getRelatedItems" action. This action load related items of a specified module. Use {cms_module module="ModuleXtender" module_name="your_module_name" module_id="your_module_item_id"}.
 It will setup a smarty variable called "mx_list". You can change that variable using the param "assign".</p> 
<h4>getOptions</h4>
<p>This action is made to obtain the list of options for a specified category. This list is given in a smarty tag.</p>
<p>List of parameters:</p>
<ul>
  <li><strong>cagetory_id:</strong> The ID of the category that you want</li>
  <li><strong>assign_to:</strong> The smarty tag that you want to create (e.g. {$options})</li>
  <li><strong>order_by:</strong> The sorting order that you can set (default is by position). Accepted values are "title asc" and "title desc"</li>
  <li><strong>related_module:</strong> Filter the results for options where a link exists into the related module</li>
</ul>
<p>&nbsp;</p>
<p>For each option items, you can get the title with getTitle() (e.g. {$item->getTitle()} and the ID of the option with getId().</p>

<h4>getRelatedItems</h4>
<p>This action put the related items of a module in a smarty variable. Use  {cms_module module="ModuleXtender" action="getRelatedItems" module_name="your_module_name" module_id="your_module_item_id" assign_to="mx_list"}</p>
<p>List of parameters:</p>
<ul>
  <li><strong>module_name:</strong> The module name (required)</li>
  <li><strong>module_id:</strong> The module item id that you want (required)</li>
  <li><strong>assign_to:</strong> The smarty tag that you want to create (e.g. {$options}) (required)</li>
</ul>
<p>&nbsp;</p>
<h4>processTemplate</h4>
<p>This action allow you to process a template stored in the ModuleXtender module. The parameters given are stored in a smarty variable called "mx_params".</p>
<p>List of parameters:</p>
<ul>
  <li><strong>template</strong> The template to use with this action</li>
</ul>
<h4>getRelationsLinks</h4>
<p>Allow you to retrieve existing relations links for a given relation and module.</p>
<p>Example: {ModuleXtender action="getRelationsLinks" relation_id="2" assign_to="test"}</p>
<p>&nbsp;</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008 <a href="http://www.morris-chapman.com/">Morris & Chapman Belgium</a>, Jean-Christophe Cuvelier <a href="mailto:jcc@morris-chapman.com">&lt;jcc@morris-chapman.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
<p>With the contribution of Benjamin Magits <a href="mailto:benjamin@morris-chapman.com">benjamin@morris-chapman.com</a>';

$lang['integration'] = 'How to make your module compatible with ModuleXtender ?';

$lang['module_integration'] = '
<h3>How to integrate ModuleXtender with your module ?</h3>
<p>You can easily integrate ModuleXtender in your module with a few steps. Follow this guide to do so.</p>
<h4>Step 1: Tweak your item management action</h4>
<p>In the action file where you mange single items, add the following codes:</p>
<p>After testing existence of $gCms:</p>
<pre>
// ModuleXtender 
$modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
</pre>
<p>Where you manages the changes after submission:</p>
<pre>
  // ModuleXtender
   if ($modulextender->isXtendedModule($this->getName()))
    {
      $modulextender->getFormInput($this->getName(), $this->item->getId(), $params);
    }
</pre>
<p>Note: The $this->item->getId() should be replaced by the id of your single item.</p>
<p>Somewhere before calling your template:</p>
<pre>
// ModuleXtender
if ($modulextender->isXtendedModule($this->getName()))
{  
  $this->smarty->assign(\'xtended_form\', $modulextender->XtendModuleForm($this->getName(), $this->item->getId(), $id));
}
else 
{
  $this->smarty->assign(\'xtended_form\', \'\');
}
</pre>
<p>Note: The $this->item->getId() should be replaced by the id of your single item. If there is no id yet, you can pass a "null"  value.</p>
<p>In your template, add the following smarty code:</p>
<pre>
{$xtended_form}
</pre>
<h4>Step 2 : Tweak the action to get list of items on frontend pages</h4>
<p>The generated $list array will content the list of id\'s from your modules that should be shown.<p>
<pre>
$modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
if (isset($params[\'currentpage\'])) {
  $list = $modulextender->relations->getRelatedModuleItemsFromCurrentPage($this->getName());
} elseif (isset($params[\'pages\'])) {
  $list = $modulextender->relations->getRelatedModuleItemsPerPage($this->getName(), explode(\',\', $params[\'pages\']));
}
</pre>
<p>Where you define values per item, you should add the values from ModuleXtender:</p>
<pre>
  $mx_datas = $modulextender->GetXtendedFrontendList($this->getName(), $item->getId(), true);
 </pre>
 <p>Note: $item->getId()  is the id of your single item.</p>
 <h4>Step 3 : Tweak the "details" action</h4>
 <p>Where you define values per item, you should add the values from ModuleXtender:</p>
<pre>
  $modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
  $mx_datas = $modulextender->GetXtendedFrontendList($this->getName(), $item->getId(), true);
 </pre>
 <p>Note: $item->getId()  is the id of your single item.</p>
 <h4>Step 4 : Enable ModuleXtender compatibility</h4>
 <p>To find all the compatible modules, ModuleXtender just look for a function in the module class. Just add the following one to enable the compatibility:</p>
 <pre>
  function XtendedModule () {
    return true;
  }
 </pre>
 <p>There you go. You should have a module compatible with ModuleXtender now.</p>
';
?>

==> ModuleXtender-1.5.1.zip: ModuleXtender/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Module Xtender';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'Post Uninstall Message, e.g., "Curses! Foiled Again!"';
$lang['really_uninstall'] = 'Really? Are you sure you want to unsinstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'This module extend compatibles modules to give them more stuffs like a categories/pages relation system, a form field extender system, etc.';

$lang['error'] = 'Error!';
$lang['submit'] = 'Submit';
$lang['apply'] = 'Apply';
$lang['upload'] = 'Upload';
$land['admin_title'] = 'Module Xtender Admin Panel';
$lang['admindescription'] = 'Manage here all your relations, module form extender, etc';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Post Install Message, (e.g., Be sure to set "" permissions to use this module!)';

$lang['modulenotdefined'] = 'Module not defined';
$lang['manage_relations'] = 'Manage relations';
$lang['noidfound'] = 'Item not found';

$lang['title_move'] = 'Move';
$lang['move_up'] = 'Move up';
$lang['move_down'] = 'Move down';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';

$lang['show'] = 'Show';
$lang['hide'] = 'Hide';

$lang['filter'] = 'Filter';
$lang['is_filter'] = 'Is a filter';
$lang['is_not_filter'] = 'Is not a filter';
$lang['is_sortable'] = 'Is sortable';
$lang['is_not_sortable'] = 'Is not sortable';
$lang['column'] = 'Column';
$lang['have_column'] = 'Have column';
$lang['dont_have_column'] = 'Do not have column';

$lang['image_file_error'] = 'An error occured with the image file.';

// TABS

$lang['devtab'] = 'Developpment Tab';
$lang['settings'] = 'Settings';
$lang['xtendedmodules'] = 'Xtended Modules';
$lang['moduleuninstalled'] = 'The module have been uninstalled !';
$lang['activemodule'] = 'Activate the module Xtended features';
$lang['desactivemodule'] = 'Desactivate the module Xtended features';

// Xtend part

$lang['isactive'] = 'Active';
$lang['option_documents_title'] = 'Show documents';
$lang['option_images_title'] = 'Show images';
$lang['option_links_title'] = 'Show links';
$lang['option_relations_title'] = 'Show relations';

// RELATIONS
$lang['relations'] = 'Relations';
$lang['rel_type_page'] = 'Page';
$lang['rel_type_pages'] = 'Subpages';
$lang['rel_type_page_and_subpages'] = 'Page & subpages';
$lang['rel_type_category'] = 'Category';
$lang['activeate_rel'] = 'Activate relation';
$lang['desactiveate_rel'] = 'Desactivate relation';

$lang['select_cat'] = 'Select a category';
$lang['select_category'] = 'Select a category';
$lang['select_module'] = 'Select a module';
$lang['add_cat'] = 'Add category';
$lang['add_page'] = 'Add page';
$lang['related_pages'] = 'Related pages';


$lang['title_type'] = 'Type';
$lang['title_visible'] = 'Show';
$lang['title_subpage'] = 'Subpage';
$lang['title_category'] = 'Category';
$lang['title_module'] = 'Module';
$lang['title_page'] = 'Page';
$lang['relation_title'] = 'Title';
$lang['edit_relation_title'] = 'Edit title';
$lang['edit_relation_title_for'] = 'Edit title for ';

$lang['title_is_filter'] = 'Is filter';
$lang['title_is_sortable'] = 'Is sortable';

$lang['manage_relations_for'] = 'Manage relations for';

// CATEGORIES / OPTIONS
$lang['categories'] = 'Categories';
$lang['title_category_name'] = 'Category name';
$lang['title_add_new_category'] = 'New category';
$lang['title_add_edit_category'] = 'Add/Edit category';
$lang['edit_cat'] = 'Edit category';
$lang['title_option_name'] = 'Option name';
$lang['title_add_new_option'] = 'New option';
$lang['title_add_edit_option'] = 'Add/Edit option';
$lang['add_option'] = 'Add option';
$lang['edit_option'] = 'Edit option';
$lang['optionadded'] = 'Option added';
$lang['optionmodified'] = 'Option modified';
$lang['optiondeleted'] = 'Option deleted';

$lang['reorder_options_alpha'] = 'Reorder options alphabeticaly';


$lang['options'] = 'Options';

$lang['options_apply_first'] = 'To add options, click on "apply" first.';
$lang['add_option_for'] = 'Add option for';

// CUSTOM FIELDS LIST
$lang['customfields'] = 'Custom Fields';
$lang['title_add_customfields'] = 'Add custom field';

// TEMPLATES

$lang['templates'] = 'Templates list';
$lang['title_list_template'] = 'Templates list';
$lang['title_details_template'] = 'Details template';
$lang['deleteTemplate'] = 'Delete template';
$lang['editTemplate'] = 'Edit template';
$lang['titleTemplate'] = 'Template name';
$lang['codeTemplate'] = 'Template code';
$lang['restorelist'] = 'Get default list template';
$lang['restoredetails'] = 'Get default details template';
$lang['title_add_template'] = 'Add template';


$lang['assigned_to'] = 'Assigned to';
$lang['get_default_template'] = 'Get default template from';
$lang['unknown_template'] = 'Unknown template';


$lang['fe.select'] = 'Select one';
$lang['fe.general'] = 'General frontend';
$lang['fe.documents'] = 'Frontend documents';
$lang['fe.images'] = 'Frontend images';
$lang['fe.pages'] = 'Frontend pages';
$lang['fe.categories'] = 'Frontend categories';


// Countries
$lang['countries_select'] = 'Select a country';

// Divers
$lang['title_selectmodule'] = 'Module';
$lang['selectmodule_button'] = 'Select module';
$lang['selectmodule_default'] = 'Select module';
$lang['areyousure'] = 'Are you sure ?';
$lang['cancel'] = 'Cancel';
$lang['firstapplydoc'] = 'First push on "Apply" or "Save & Continue" to be able to add documents';
$lang['firstapplyimg'] = 'First push on "Apply" or "Save & Continue" to be able to add images';
$lang['firstapplylink'] = 'First push on "Apply" or "Save & Continue" to be able to add links';
$lang['tips'] = 'Tips:';
$lang['tips1'] = 'To select multiple relations use CTRL+Click.<br />To unselect an item, use CTRL+Click.';
$lang['title'] = 'Title';
$lang['caption'] = 'Caption';
$lang['file'] = 'File';

$lang['document'] = 'Document';
$lang['documents'] = 'Documents';

$lang['image'] = 'Image';
$lang['images'] = 'Images';
$lang['rebuild_thumbnails'] = 'Rebuild thumbnails';
$lang['reset_sizes'] = 'Reset image sizes';

$lang['link'] = 'Link';
$lang['links'] = 'Links';
$lang['popup_link'] = 'Popup link';
$lang['popup_link_question'] = 'Popup link?';
$lang['is_new_window'] = 'Show in new window';
$lang['isnt_new_window'] = 'Dont show in new window';
$lang['url'] = 'Url';


// Related categories

$lang['related_categories'] = 'Related categories';
$lang['manage_related_categories_for'] = 'Manage %2 related categories for module %1';
$lang['back_to_xtended'] = 'Return to %1 options list';
$lang['manage_related_categories'] = 'Manage related categories';

// Divers
$lang['cleanup'] = 'Cleanup module';
$lang['load_deprecated_features'] = 'Load deprecated features'; 


// ModuleXtender Smarty Available fields

$lang['smarty_fields'] = '
<ul>
  <li>$item->xtended_felist</li>
</ul>';



$lang['changelog'] = '<ul>
<li>Version 0.1.15 - 27 july 2009. Add related links</li>
<li>Version 0.1.14 - 25 july 2009. Add lot of stuff</li>
<li>Version 0.0.5 - 17 january 2009. Add the ability to make relation to page and subpages and clean some stuff.</li>
<li>Version 0.0.4.3 - 16 april 2008. Add several features and fixes.</li>
<li>Version 0.0.2.6 - 16 october 2007. Correct thumbs size calculation.</li>
<li>Version 0.0.2.5 - 15 october 2007. First official Release.</li>
<li>Version 0.0.1 - 24 August 2007. Initial Release.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module extend compatibles modules to give them more stuffs like a categories/pages relation system, a form field extender system, etc.</p>
<h3>How Do I Use It</h3>
<p>It will generate appropriate fields in the compatible module, in the frontend and the backend.</p>

<h3>What Parameters Does It Take</h3>
<p>This take many parameters. Here is a short list of it.</p>
<ul>
  <li><strong>pages</strong> Filter on given pages id separate by a ",".</li>
  <li><strong>subpages</strong> Filter on subpages from given page id.</li>
  <li><strong>currentpage</strong> Filter on current page.</li>
  <li><strong>category</strong> Filter on given category id.</li>
  <li><strong>categories</strong> Filter on given categories id separate by a ",".</li>
  <li><strong>filter_on</strong> filters on different attributes. The form is filter_on="type1|params||type2|params" where types can be "pages", "categories", and "field". For field, the params are like filter_on="field|fieldname=value".</li>
</ul>
<p>&nbsp;</p>
<h3>Front End Actions</h3>
<p>&nbsp;</p>
<h4>Default</h4>
<p>Deprecated: Prefere the use of "getRelatedItems" action. This action load related items of a specified module. Use {cms_module module="ModuleXtender" module_name="your_module_name" module_id="your_module_item_id"}.
 It will setup a smarty variable called "mx_list". You can change that variable using the param "assign".</p> 
<h4>getOptions</h4>
<p>This action is made to obtain the list of options for a specified category. This list is given in a smarty tag.</p>
<p>List of parameters:</p>
<ul>
  <li><strong>cagetory_id:</strong> The ID of the category that you want</li>
  <li><strong>assign_to:</strong> The smarty tag that you want to create (e.g. {$options})</li>
  <li><strong>order_by:</strong> The sorting order that you can set (default is by position). Accepted values are "title asc" and "title desc"</li>
  <li><strong>related_module:</strong> Filter the results for options where a link exists into the related module</li>
</ul>
<p>&nbsp;</p>
<p>For each option items, you can get the title with getTitle() (e.g. {$item->getTitle()} and the ID of the option with getId().</p>

<h4>getRelatedItems</h4>
<p>This action put the related items of a module in a smarty variable. Use  {cms_module module="ModuleXtender" action="getRelatedItems" module_name="your_module_name" module_id="your_module_item_id" assign_to="mx_list"}</p>
<p>List of parameters:</p>
<ul>
  <li><strong>module_name:</strong> The module name (required)</li>
  <li><strong>module_id:</strong> The module item id that you want (required)</li>
  <li><strong>assign_to:</strong> The smarty tag that you want to create (e.g. {$options}) (required)</li>
</ul>
<p>&nbsp;</p>
<h4>processTemplate</h4>
<p>This action allow you to process a template stored in the ModuleXtender module. The parameters given are stored in a smarty variable called "mx_params".</p>
<p>List of parameters:</p>
<ul>
  <li><strong>template</strong> The template to use with this action</li>
</ul>
<h4>getRelationsLinks</h4>
<p>Allow you to retrieve existing relations links for a given relation and module.</p>
<p>Example: {ModuleXtender action="getRelationsLinks" relation_id="2" assign_to="test"}</p>
<p>&nbsp;</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008 <a href="http://www.morris-chapman.com/">Morris & Chapman Belgium</a>, Jean-Christophe Cuvelier <a href="mailto:jcc@morris-chapman.com">&lt;jcc@morris-chapman.com&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
<p>With the contribution of Benjamin Magits <a href="mailto:benjamin@morris-chapman.com">benjamin@morris-chapman.com</a>';

$lang['integration'] = 'How to make your module compatible with ModuleXtender ?';

$lang['module_integration'] = '
<h3>How to integrate ModuleXtender with your module ?</h3>
<p>You can easily integrate ModuleXtender in your module with a few steps. Follow this guide to do so.</p>
<h4>Step 1: Tweak your item management action</h4>
<p>In the action file where you mange single items, add the following codes:</p>
<p>After testing existence of $gCms:</p>
<pre>
// ModuleXtender 
$modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
</pre>
<p>Where you manages the changes after submission:</p>
<pre>
  // ModuleXtender
   if ($modulextender->isXtendedModule($this->getName()))
    {
      $modulextender->getFormInput($this->getName(), $this->item->getId(), $params);
    }
</pre>
<p>Note: The $this->item->getId() should be replaced by the id of your single item.</p>
<p>Somewhere before calling your template:</p>
<pre>
// ModuleXtender
if ($modulextender->isXtendedModule($this->getName()))
{  
  $this->smarty->assign(\'xtended_form\', $modulextender->XtendModuleForm($this->getName(), $this->item->getId(), $id));
}
else 
{
  $this->smarty->assign(\'xtended_form\', \'\');
}
</pre>
<p>Note: The $this->item->getId() should be replaced by the id of your single item. If there is no id yet, you can pass a "null"  value.</p>
<p>In your template, add the following smarty code:</p>
<pre>
{$xtended_form}
</pre>
<h4>Step 2 : Tweak the action to get list of items on frontend pages</h4>
<p>The generated $list array will content the list of id\'s from your modules that should be shown.<p>
<pre>
$modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
if (isset($params[\'currentpage\'])) {
  $list = $modulextender->relations->getRelatedModuleItemsFromCurrentPage($this->getName());
} elseif (isset($params[\'pages\'])) {
  $list = $modulextender->relations->getRelatedModuleItemsPerPage($this->getName(), explode(\',\', $params[\'pages\']));
}
</pre>
<p>Where you define values per item, you should add the values from ModuleXtender:</p>
<pre>
  $mx_datas = $modulextender->GetXtendedFrontendList($this->getName(), $item->getId(), true);
 </pre>
 <p>Note: $item->getId()  is the id of your single item.</p>
 <h4>Step 3 : Tweak the "details" action</h4>
 <p>Where you define values per item, you should add the values from ModuleXtender:</p>
<pre>
  $modulextender = $gCms->modules[\'ModuleXtender\'][\'object\'];
  $mx_datas = $modulextender->GetXtendedFrontendList($this->getName(), $item->getId(), true);
 </pre>
 <p>Note: $item->getId()  is the id of your single item.</p>
 <h4>Step 4 : Enable ModuleXtender compatibility</h4>
 <p>To find all the compatible modules, ModuleXtender just look for a function in the module class. Just add the following one to enable the compatibility:</p>
 <pre>
  function XtendedModule () {
    return true;
  }
 </pre>
 <p>There you go. You should have a module compatible with ModuleXtender now.</p>
';
?>
